![](/images/icon.png)

# Release Notes

## New Features
- Feature 1: Description of feature 1.

## Improvements
- Improvement 1: Description of improvement 1.

## Bug Fixes
- Bug Fix 1: Description of bug fix 1.

## Other Changes
- Other change 1: Description of other change 1.

## Important notes:
- Make sure your machine is on the latest firmware from https://github.com/Zer0-bit/gaggiuino/releases.
- The firmware that offers this API Endpoint has not yet been released. This release will be marked as the latest (not pre-release) as soon as the firmware is released.
- As of this moment, this API endpoint is supported only by a pre-release firmware from this [thread](https://discord.com/channels/890339612441063494/1343968769499992105/1343968895261872299)
